==> daal-devel-2018.0.0.20170814-0.tar.bz2: pydaal_sources/daal/algorithms/linear_model/training.py <==
# Copyright 2014-2017 Intel Corporation
# All Rights Reserved.
#
# If this  software was obtained  under the  Intel Simplified  Software License,
# the following terms apply:
#
# The source code,  information  and material  ("Material") contained  herein is
# owned by Intel Corporation or its  suppliers or licensors,  and  title to such
# Material remains with Intel  Corporation or its  suppliers or  licensors.  The
# Material  contains  proprietary  information  of  Intel or  its suppliers  and
# licensors.  The Material is protected by  worldwide copyright  laws and treaty
# provisions.  No part  of  the  Material   may  be  used,  copied,  reproduced,
# modified, published,  uploaded, posted, transmitted,  distributed or disclosed
# in any way without Intel's prior express written permission.  No license under
# any patent,  copyright or other  intellectual property rights  in the Material
# is granted to  or  conferred  upon  you,  either   expressly,  by implication,
# inducement,  estoppel  or  otherwise.  Any  license   under such  intellectual
# property rights must be express and approved by Intel in writing.
#
# Unless otherwise agreed by Intel in writing,  you may not remove or alter this
# notice or  any  other  notice   embedded  in  Materials  by  Intel  or Intel's
# suppliers or licensors in any way.
#
#
# If this  software  was obtained  under the  Apache License,  Version  2.0 (the
# "License"), the following terms apply:
#
# You may  not use this  file except  in compliance  with  the License.  You may
# obtain a copy of the License at http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless  required  by   applicable  law  or  agreed  to  in  writing,  software
# distributed under the License  is distributed  on an  "AS IS"  BASIS,  WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the   License  for the   specific  language   governing   permissions  and
# limitations under the License.


from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_training11', [dirname(__file__)])
        except ImportError:
            import _training11
            return _training11
        if fp is not None:
            try:
                _mod = imp.load_module('_training11', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _training11 = swig_import_helper()
    del swig_import_helper
else:
    import _training11
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.linear_model
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.data_feature_utils
import daal.algorithms.regression
import daal.algorithms.regression.training

_training11.data_swigconstant(_training11)
data = _training11.data

_training11.dependentVariables_swigconstant(_training11)
dependentVariables = _training11.dependentVariables

_training11.lastInputId_swigconstant(_training11)
lastInputId = _training11.lastInputId

_training11.model_swigconstant(_training11)
model = _training11.model

_training11.lastResultId_swigconstant(_training11)
lastResultId = _training11.lastResultId
class Input(daal.algorithms.regression.training.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _training11.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _training11.delete_Input
    __del__ = lambda self: None

    def get(self, id):
        return _training11.Input_get(self, id)

    def set(self, id, value):
        return _training11.Input_set(self, id, value)
Input_swigregister = _training11.Input_swigregister
Input_swigregister(Input)

class PartialResult(daal.algorithms.regression.training.PartialResult):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.PartialResult]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, PartialResult, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.PartialResult]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, PartialResult, name)
    __repr__ = _swig_repr

    def __init__(self, nElements=0):
        this = _training11.new_PartialResult(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _training11.delete_PartialResult
    __del__ = lambda self: None
PartialResult_swigregister = _training11.PartialResult_swigregister
PartialResult_swigregister(PartialResult)

class Result(daal.algorithms.regression.training.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr

    def __init__(self, nElements=0):
        this = _training11.new_Result(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this

    def get(self, id):
        return _training11.Result_get(self, id)

    def set(self, id, value):
        return _training11.Result_set(self, id, value)

    def check(self, input, par, method):
        return _training11.Result_check(self, input, par, method)
    __swig_destroy__ = _training11.delete_Result
    __del__ = lambda self: None
Result_swigregister = _training11.Result_swigregister
Result_swigregister(Result)

class Batch(daal.algorithms.regression.training.Batch):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getResult(self):
        return _training11.Batch_getResult(self)

    def compute(self):
        return _training11.Batch_compute(self)
    __swig_destroy__ = _training11.delete_Batch
    __del__ = lambda self: None
Batch_swigregister = _training11.Batch_swigregister
Batch_swigregister(Batch)

class Online(daal.algorithms.regression.training.Online):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Online]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Online, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Online]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Online, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getPartialResult(self):
        return _training11.Online_getPartialResult(self)

    def getResult(self):
        return _training11.Online_getResult(self)

    def compute(self):
        return _training11.Online_compute(self)
    __swig_destroy__ = _training11.delete_Online
    __del__ = lambda self: None
Online_swigregister = _training11.Online_swigregister
Online_swigregister(Online)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.

==> daal-devel-2020.0-166.tar.bz2: pydaal_sources/daal/algorithms/linear_model/training.py <==
# Copyright 2014-2019 Intel Corporation
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.



from sys import version_info
if version_info >= (2, 6, 0):
    def swig_import_helper():
        from os.path import dirname
        import imp
        fp = None
        try:
            fp, pathname, description = imp.find_module('_training14_', [dirname(__file__)])
        except ImportError:
            import _training14_
            return _training14_
        if fp is not None:
            try:
                _mod = imp.load_module('_training14_', fp, pathname, description)
            finally:
                fp.close()
            return _mod
    _training14_ = swig_import_helper()
    del swig_import_helper
else:
    import _training14_
del version_info
try:
    _swig_property = property
except NameError:
    pass  # Python < 2.2 doesn't have 'property'.


def _swig_setattr_nondynamic(self, class_type, name, value, static=1):
    if (name == "thisown"):
        return self.this.own(value)
    if (name == "this"):
        if type(value).__name__ == 'SwigPyObject':
            self.__dict__[name] = value
            return
    method = class_type.__swig_setmethods__.get(name, None)
    if method:
        return method(self, value)
    if (not static):
        if _newclass:
            object.__setattr__(self, name, value)
        else:
            self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)


def _swig_setattr(self, class_type, name, value):
    return _swig_setattr_nondynamic(self, class_type, name, value, 0)


def _swig_getattr_nondynamic(self, class_type, name, static=1):
    if (name == "thisown"):
        return self.this.own()
    method = class_type.__swig_getmethods__.get(name, None)
    if method:
        return method(self)
    if (not static):
        return object.__getattr__(self, name)
    else:
        raise AttributeError(name)

def _swig_getattr(self, class_type, name):
    return _swig_getattr_nondynamic(self, class_type, name, 0)


def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)

try:
    _object = object
    _newclass = 1
except AttributeError:
    class _object:
        pass
    _newclass = 0


try:
    import weakref
    weakref_proxy = weakref.proxy
except:
    weakref_proxy = lambda x: x


import daal.algorithms.linear_model
import daal.algorithms
import daal.data_management
import daal
import daal.services
import daal.data_management.features
import daal.data_management.modifiers.csv
import daal.data_management.modifiers
import daal.algorithms.regression
import daal.algorithms.regression.training

_training14_.data_swigconstant(_training14_)
data = _training14_.data

_training14_.dependentVariables_swigconstant(_training14_)
dependentVariables = _training14_.dependentVariables

_training14_.lastInputId_swigconstant(_training14_)
lastInputId = _training14_.lastInputId

_training14_.model_swigconstant(_training14_)
model = _training14_.model

_training14_.lastResultId_swigconstant(_training14_)
lastResultId = _training14_.lastResultId
class Input(daal.algorithms.regression.training.Input):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Input]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Input, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Input]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Input, name)
    __repr__ = _swig_repr

    def __init__(self, *args):
        this = _training14_.new_Input(*args)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _training14_.delete_Input
    __del__ = lambda self: None

    def get(self, id):
        return _training14_.Input_get(self, id)

    def set(self, id, value):
        return _training14_.Input_set(self, id, value)
Input_swigregister = _training14_.Input_swigregister
Input_swigregister(Input)

class PartialResult(daal.algorithms.regression.training.PartialResult):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.PartialResult]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, PartialResult, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.PartialResult]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, PartialResult, name)
    __repr__ = _swig_repr

    def __init__(self, nElements=0):
        this = _training14_.new_PartialResult(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this
    __swig_destroy__ = _training14_.delete_PartialResult
    __del__ = lambda self: None
PartialResult_swigregister = _training14_.PartialResult_swigregister
PartialResult_swigregister(PartialResult)

class Result(daal.algorithms.regression.training.Result):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Result]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Result, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Result]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Result, name)
    __repr__ = _swig_repr

    def __init__(self, nElements=0):
        this = _training14_.new_Result(nElements)
        try:
            self.this.append(this)
        except:
            self.this = this

    def get(self, id):
        return _training14_.Result_get(self, id)

    def set(self, id, value):
        return _training14_.Result_set(self, id, value)

    def check(self, input, par, method):
        return _training14_.Result_check(self, input, par, method)
    __swig_destroy__ = _training14_.delete_Result
    __del__ = lambda self: None
Result_swigregister = _training14_.Result_swigregister
Result_swigregister(Result)

class Batch(daal.algorithms.regression.training.Batch):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Batch]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Batch, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Batch]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Batch, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getResult(self):
        return _training14_.Batch_getResult(self)

    def compute(self):
        return _training14_.Batch_compute(self)
    __swig_destroy__ = _training14_.delete_Batch
    __del__ = lambda self: None
Batch_swigregister = _training14_.Batch_swigregister
Batch_swigregister(Batch)

class Online(daal.algorithms.regression.training.Online):
    __swig_setmethods__ = {}
    for _s in [daal.algorithms.regression.training.Online]:
        __swig_setmethods__.update(getattr(_s, '__swig_setmethods__', {}))
    __setattr__ = lambda self, name, value: _swig_setattr(self, Online, name, value)
    __swig_getmethods__ = {}
    for _s in [daal.algorithms.regression.training.Online]:
        __swig_getmethods__.update(getattr(_s, '__swig_getmethods__', {}))
    __getattr__ = lambda self, name: _swig_getattr(self, Online, name)

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def getPartialResult(self):
        return _training14_.Online_getPartialResult(self)

    def getResult(self):
        return _training14_.Online_getResult(self)

    def compute(self):
        return _training14_.Online_compute(self)
    __swig_destroy__ = _training14_.delete_Online
    __del__ = lambda self: None
Online_swigregister = _training14_.Online_swigregister
Online_swigregister(Online)

from numpy import float64, float32, intc


# This file is compatible with both classic and new-style classes.
